@@ -1,6 +1,7 @@
 /*******************************************************************
  * reportassistantpage.cpp
  * SPDX-FileCopyrightText: 2009 Dario Andres Rodriguez <andresbajotierra@gmail.com>
+ * SPDX-FileCopyrightText: 2021 Harald Sitter <sitter@kde.org>
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
  *
@@ -20,6 +21,11 @@ bool ReportAssistantPage::isComplete()
     return true;
 }
 
+bool ReportAssistantPage::isAppropriate()
+{
+    return true;
+}
+
 bool ReportAssistantPage::showNextPage()
 {
     return true;
@@ -42,5 +48,5 @@ ReportAssistantDialog *ReportAssistantPage::assistant() const
 
 void ReportAssistantPage::emitCompleteChanged()
 {
-    emit completeChanged(this, isComplete());
+    Q_EMIT completeChanged(this, isComplete());
 }
