@@ -14,6 +14,7 @@
 
 #include "reportassistantdialog.h"
 #include "reportassistantpage.h"
+#include "reportinterface.h"
 
 #include "ui_assistantpage_bugawareness.h"
 #include "ui_assistantpage_conclusions.h"
@@ -67,50 +68,10 @@ private Q_SLOTS:
 
 private:
     Ui::AssistantPageBugAwareness ui;
-};
-
-/** Conclusions page **/
-class ConclusionPage : public ReportAssistantPage
-{
-    Q_OBJECT
-
-public:
-    explicit ConclusionPage(ReportAssistantDialog *);
-
-    void aboutToShow() override;
-    void aboutToHide() override;
-
-    bool isComplete() override;
-
-private Q_SLOTS:
-    void finishClicked();
-
-    void openReportInformation();
-
-private:
-    Ui::AssistantPageConclusions ui;
-
-    QPointer<QDialog> m_infoDialog;
-
-    bool m_isBKO;
-    bool m_needToReport;
-
-Q_SIGNALS:
-    void finished(bool);
-};
-
-class ReportInformationDialog : public QDialog
-{
-    Q_OBJECT
-public:
-    explicit ReportInformationDialog(const QString &reportText);
-    ~ReportInformationDialog() override;
-
-private Q_SLOTS:
-    void saveReport();
-
-private:
-    Ui::AssistantPageConclusionsDialog ui;
+    const QHash<int, ReportInterface::Reproducible> m_reproducibleIndex{{0, ReportInterface::ReproducibleUnsure},
+                                                                        {1, ReportInterface::ReproducibleNever},
+                                                                        {2, ReportInterface::ReproducibleSometimes},
+                                                                        {3, ReportInterface::ReproducibleEverytime}};
 };
 
 #endif
